function checkerror=showbridge(nameroo,option,patooi)
% showbridge(nameroo,option)
%===============================================================================================
% SHOWBRIDGE(NAMEROO,OPTION) 
%
% NAMEROO = full file name of output file (class:  string)
% *OPTION = used by GUI callbacks only
%===============================================================================================

% Kevin Mackie, 2/22/02
% University of California, Berkeley
% mackie@ce.berkeley.edu

if nargin==1
    % OBTAIN STRUCTURAL VALUES FROM PRINTOUT FILE
       fid = fopen(nameroo,'rt');      % open output file
       
       if fid == -1
           disp(['''' nameroo '''' ' is not a valid accessible file']);    % sets the file position indicator to the beginning
       else                                                                % of the file associated with file identifier fid
           frewind(fid);                                                   % and catches any errors if an invalid file is called
       end                                                      
    
       NODENUMS = [];
     ZEROLENGTH = [];
       ELEMENTS = [];
           AMPL = [];
    
    while ~feof(fid)
        fileline = fgetl(fid);
        
      isnode = strcmp('node',lower(strtok(fileline)));
       isfix = strcmp('fix',lower(strtok(fileline)));
   iselement = strcmp('element',lower(strtok(fileline)));
   ismodelin = strcmp('model',lower(strtok(fileline)));
        
        switch 1
        case ismodelin
            [waste,newfileline] = strtok(lower(fileline(findstr(lower(fileline),'-ndm'):end)));
              [ndm,newfileline] = strtok(lower(newfileline));
                    [waste,ndf] = strtok(lower(newfileline));
            ndm = str2num(ndm);          ndf = str2num(ndf);
        case isnode
            newfileline = strtok(lower(fileline),'node');
            ismass = findstr(' -mass ',newfileline);
            
            if ~isempty(ismass)
                newfileline = newfileline(1:ismass);
            end
            
            newfileline = str2num(newfileline);
            NODENUMS = [NODENUMS; newfileline(1)];
            NODES(newfileline(1),:) = newfileline(2:end);
        case isfix
            newfileline = strtok(lower(fileline),'fix');
            newfileline = str2num(newfileline);
            FIXES(newfileline(1),:) = newfileline(2:end);
        case iselement
            [comment,newfileline] = strtok(fileline);
            [comment,newfileline] = strtok(newfileline);
            
            if strcmp('zeroLength',comment)
                           placement = findstr(newfileline,' -mat ');
                     wannabenew.conn = str2num(newfileline(1:placement));
               [comment,newfileline] = strtok(newfileline(placement:end));
               
                           placement = findstr(newfileline,' -dir ');
                      wannabenew.mat = str2num(newfileline(1:placement));
               [comment,newfileline] = strtok(newfileline(placement:end));
               
                           placement = findstr(newfileline,' -orient ');
                      wannabenew.dir = str2num(newfileline(1:placement));
               [comment,newfileline] = strtok(newfileline(placement:end));
              
               if ~isempty(comment)
                   wannabenew.orient = str2num(newfileline(1:end));
               end
      ZEROLENGTH{wannabenew.conn(1)} = wannabenew;
            else
                   rownum = size(ELEMENTS,1)+1;
              newfileline = str2num(newfileline);
       ELEMENTS(rownum,:) = newfileline(1:3);
            end
        end
    end
    
    fclose(fid);
    NODENUMS = sort(NODENUMS);
    clear isnode isfix iselement ismass newfileline wannabenew rownum placement comment fileline
    
    % STORE PARSED INFORMATION INTO 'INFO' VARIABLE
    info.zerolength = ZEROLENGTH;   info.elements = ELEMENTS;   info.fixes = FIXES;
    info.nodes = NODES;             info.nodenums = NODENUMS;     info.ndm = ndm;        info.ndf = ndf;
    
    connections = ELEMENTS(:,2:3);
    
    if ndm == 2
        XYZ = NODES;     XYZ(:,3) = 0;     XYZ = XYZ';
    else
        XYZ = NODES';
    end
    
    X(1,:) = XYZ(1,connections(:,1));     X(2,:) = XYZ(1,connections(:,2));
    Y(1,:) = XYZ(2,connections(:,1));     Y(2,:) = XYZ(2,connections(:,2));
    Z(1,:) = XYZ(3,connections(:,1));     Z(2,:) = XYZ(3,connections(:,2));
    
    % STORE NODAL INFORMATION
    diffmode.X{1} = X;   diffmode.Y{1} = Y;   diffmode.Z{1} = Z;
    
    % INITIALIZE VARIABLE:  FILENAME, MENUNAME, MAGICNUM, NEWEIGENVALUES, AMPL
    filename{1} = nameroo;          menuname{1} = 'Structure';       AMPL = [];
       magicnum = 1;             neweigenvalues = -1;
    
    % OBTAIN EIGENVALUES
         nameroo = strtok(nameroo,'.');       % remove '.tcl' from name
    info.nameroo = nameroo;                   % save filename
    
    
    fid = fopen([nameroo 'EIGENVALS.out'],'rt');       % open output file
    frewind(fid);     % sets the file position indicator to the beginning
    eigenvalues = fgetl(fid);   eigenvalues = str2num(eigenvalues);   nummodes=size(eigenvalues,2);
    fclose(fid);
    
    menulist = 'Structure';               save_quest = 1;
    
    % INITIALIZE FIGURE
    Hfig = figure('NumberTitle','off','Units','normalized','Position',[0.2500  0.1000  0.65  0.7500],...
                  'Name',nameroo,'Color',[0 0 0],'CloseRequestFCN','showbridge(''filename'',''close_sub''); delete(gcf)');
              
    if ndm == 3; view(3); end
   
    % OBTAIN NODAL DISPLACEMENTS FOR CORRESPONDING EIGNEVALUES
    for k=1:nummodes
        % OPEN OUTPUT FILE, CATCH IF FILE NOT AVAILABLE
        fid = fopen([nameroo 'mode' num2str(k) '.out'],'rt');     % open output file
        
        % CHECK IF FILE IS PRESENT
        if fid == -1
            disp(['could not find ' strtok(nameroo,'.') 'mode' num2str(k) '.tcl']);
        else
            AMPL = [AMPL 200];
            magicnum = magicnum + 1;
            neweigenvalues = [neweigenvalues eigenvalues(k)];
            filename{magicnum} = [nameroo 'mode' num2str(k) '.out'];
            
            frewind(fid);            % sets the file position indicator to the beginning
            
            % PARSE NUMBERS INTO VARIABLE 'FILELINE'
            fileline = fgetl(fid);   fileline = str2num(fileline);   numcol = size(fileline,2);
            diffmode.FILE{magicnum} = fileline;
            
            % SORT DISPLACEMENTS ACCORDING TO NODES AND DOF
            diffXYZ(1,NODENUMS) = fileline(1:3:numcol);
            diffXYZ(2,NODENUMS) = fileline(2:3:numcol);
            diffXYZ(3,NODENUMS) = fileline(3:3:numcol);
            
            % NORMALIZE DISPLACEMENT
            resultant = sqrt([sum(diffXYZ.^2,2)]);
            diffXYZ = diffXYZ/max(resultant);
            
            % SORT DISPLACEMENTS BY CONNECTIONS
            diffX(1,:) = diffXYZ(1,connections(:,1));   diffX(2,:) = diffXYZ(1,connections(:,2));
            diffY(1,:) = diffXYZ(2,connections(:,1));   diffY(2,:) = diffXYZ(2,connections(:,2));
            diffZ(1,:) = diffXYZ(3,connections(:,1));   diffZ(2,:) = diffXYZ(3,connections(:,2));
            
            % PLOT LINES SHOWING NODAL DISPLACEMENT (SHOWING MOVEMENT OF NODE FROM ORIGIN TO DISPLACED POSITION)
            moveX(1,:) = XYZ(1,NODENUMS);   moveX(2,:) = moveX(1,:) + AMPL(k)*diffXYZ(1,NODENUMS);
            moveY(1,:) = XYZ(2,NODENUMS);   moveY(2,:) = moveY(1,:) + AMPL(k)*diffXYZ(2,NODENUMS);
            moveZ(1,:) = XYZ(3,NODENUMS);   moveZ(2,:) = moveZ(1,:) + AMPL(k)*diffXYZ(3,NODENUMS);
            
            % STORE DISPLACEMENTS FOR SHAPES OF EIGEN MODES

            diffmode.wacky{magicnum} = 1;           diffmode.all{magicnum} = diffXYZ;   diffmode.max_res{magicnum} = max(resultant);
                diffmode.X{magicnum} = diffX;         diffmode.Y{magicnum} = diffY;           diffmode.Z{magicnum} = diffZ;
            diffmode.moveX{magicnum} = moveX;     diffmode.moveY{magicnum} = moveY;       diffmode.moveZ{magicnum} = moveZ;
            
            % PLOT LINES
            Xdat = X + AMPL(magicnum-1)*diffX;     Ydat = Y + AMPL(magicnum-1)*diffY;     Zdat = Z + AMPL(magicnum-1)*diffZ;
            
            info.lines{magicnum} = line(Xdat,Ydat,Zdat,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle','none','MarkerSize',8);
        info.movelines{magicnum} = line(moveX,moveY,moveZ,'Color',[0.753 0.753 0.753],'LineWidth',[0.5],'LineStyle','none','MarkerSize',8);
                        menulist = [menulist '|' 'Mode ' num2str(k)];
              menuname{magicnum} = ['Mode ' num2str(k)];
            
            fclose(fid);
            clear fid fileline diffXYZ diffX diffY diffZ
        end
    end
    
    % STORE MORE PARSED INFORMATION INTO 'INFO' VARIALBE
    info.eigen = neweigenvalues;   info.magicnum = magicnum;   info.diffmode = diffmode;
    info.menulist = menulist;      info.filename = filename;   info.menuname = menuname;
    
    % DISPLAY STRUCTURAL MODEL
    info.lines{1} = line(X,Y,Z,'Color',[1 1 1],'LineWidth',[1.5],'LineStyle','-','MarkerSize',18);
        info.axes = get(info.lines{1}(1),'Parent');
    set(info.axes,'Units','normalized','Position',[0.1 0.1 0.8 0.75],'Color','none','Box','off',...
                  'Visible','off','XColor',[1 1 1],'YColor',[1 1 1],'ZColor',[1 1 1]);
    axis image
              
    % CREATE OBJECTS IN FIGURE
    info.frame = uicontrol(Hfig,'Style','frame','Units','normalized','Position',[0.0 0.85 1.0 0.15],'BackgroundColor',[0 0 0]);
    
     info.menu = uicontrol(Hfig,'Style','popupmenu','CallBack','showbridge(''filename'',''menu'');',...
                                'Units','normalized','Position',[0.05 0.85 0.15 0.10],...
                                'String',menulist,'Value',1,'UserData',1);
    
        info.T = uicontrol(Hfig,'Style','text','Units','normalized','Position',[0.225 0.91 0.075 0.05],...
                                'BackgroundColor',[0 0 0],'FontSize',20,'ForegroundColor',[0 0 0],...
                                'FontWeight','bold','FontName','Book Antiqua','String','T =','Enable','on');
    
     info.disp = uicontrol(Hfig,'Style','text','Units','normalized','Position',[0.30 0.913 0.10 0.03],'FontSize',10,...
                                'FontName','Book Antiqua','BackgroundColor',[0 0 0],'ForegroundColor',[1 1 1],...
                                'String','','Enable','off','HorizontalAlignment','left');
                            
  info.seconds = uicontrol(Hfig,'Style','text','Units','normalized','Position',[0.40 0.913 0.03 0.03],'FontSize',10,...
                                'FontName','Book Antiqua','BackgroundColor',[0 0 0],'ForegroundColor',[0 0 0],...
                                'String','s','Enable','on','HorizontalAlignment','left');
    
    % PUSHBUTTON PLACEMENTS
    % [0.7   0.94 0.08   0.03], [0.8   0.94 0.08   0.03], [0.9   0.94 0.08   0.03]
    % [0.7   0.9  0.08   0.03], [0.8   0.9  0.08   0.03], [0.9   0.9  0.08   0.03]
    % [0.7   0.86 0.08   0.03], [0.8   0.86 0.035  0.03], [0.845 0.86 0.035  0.03], [0.9 0.86 0.08 0.03]
    
 info.nostruct = uicontrol(Hfig,'Style','pushbutton',...
                                'Units','normalized','Position',[0.55 0.94 0.12 0.03],'FontWeight','bold',...
                                'String','STRUCT','CallBack','showbridge(''filename'',''nostruct'');');
                            
   info.nodebt = uicontrol(Hfig,'Style','pushbutton',...
                                'Units','normalized','Position',[0.55 0.9  0.12 0.03],...
                                'String','NODES','CallBack','showbridge(''filename'',''nodebutton'');');
                          
   info.axesbt = uicontrol(Hfig,'Style','pushbutton',...
                                'Units','normalized','Position',[0.55 0.86 0.12 0.03],...
                                'String','AXES','CallBack','showbridge(''filename'',''axesbutton'');');
                      
      info.eps = uicontrol(Hfig,'Style','pushbutton','UserData',0,...
                                'Units','normalized','Position',[0.70 0.94 0.12 0.03],...
                                'String','EPS','CallBack','showbridge(''filename'',''eps'');');
                                
   info.rotate = uicontrol(Hfig,'Style','pushbutton',...
                                'Units','normalized','Position',[0.70 0.9  0.12 0.03],...
                                'String','ROTATE','CallBack','showbridge(''filename'',''rotate'');');
                                
     info.zoom = uicontrol(Hfig,'Style','pushbutton',...
                                'Units','normalized','Position',[0.70 0.86 0.12 0.03],...
                                'String','ZOOM','CallBack','showbridge(''filename'',''zoom'');');
     
  info.amplify = uicontrol(Hfig,'Style','edit','UserData',AMPL,...
                                'Units','normalized','Position',[0.85 0.94 0.12 0.03],'Enable','Off',...
                                'String','','CallBack','showbridge(''filename'',''amplify'');');

   info.nomode = uicontrol(Hfig,'Style','pushbutton','UserData','--','Enable','Off',...
                                'Units','normalized','Position',[0.85 0.9  0.12 0.03],'FontWeight','bold',...
                                'String','MODE','CallBack','showbridge(''filename'',''nomode'');');

 info.displace = uicontrol(Hfig,'Style','pushbutton','Enable','Off','UserData','none',...
                                'Units','normalized','Position',[0.85 0.86  0.12 0.03],...
                                'String','DISP','CallBack','showbridge(''filename'',''displace'');');
                            
    % CREATE OBJECTS IN MENU
        info.Hoptmenu = uimenu(Hfig,'Label','&Option');
          info.Hm_add = uimenu(info.Hoptmenu,'Label','Add Mode/Displacement','Accelerator','A','UserData',0,...
                                             'Checked','off','Callback','showbridge(''filename'',''addmoddisp'');');
        info.Hm_movie = uimenu(info.Hoptmenu,'Label','Make Movie','Accelerator','M','UserData',0,'Checked','off','Callback','showbridge(''filename'',''makemovie'');');
end

if nargin==2
   Hfig = gcbf;   set(Hfig,'HandleVisibility','on');

   if ~isstruct(get(Hfig,'UserData'))
       Hfig = get(gcbf,'UserData');
   end
   
   info = get(Hfig,'UserData');
   save_quest = 1;
   
   switch option
   case 'makemovie'
       iscreated = get(info.Hm_movie,'UserData');
       if iscreated == 0
           set(info.Hm_movie,'UserData',1,'Enable','off')
           info.sub_movieHfig = figure('NumberTitle','off','Units','normalized','Position',[0.5500  0.6500  0.30  0.20],...
                                       'Name','Make Movie','Color',[0 0 0],'UserData',Hfig, ...
                                       'menubar','none','CloseRequestFCN','showbridge(''filename'',''close_sub'');');
           info.sub_moviemenu = uicontrol(info.sub_movieHfig,'Style','listbox','Units','normalized','Position',[0.1 0.3 0.8 0.65],'String',info.menulist,'Callback','showbridge(''filename'',''sub_moviSELECT'')');
             info.sub_MAKEMOVIE = uicontrol(info.sub_movieHfig,'Style','pushbutton','Units','normalized','Position',[0.65 0.075 0.3 0.15], ...
                                                               'Enable','off','String','MAKE MOVIE','HorizontalAlignment','center','FontWeight','bold', ...
                                                               'FontName','Times New Roman','FontSize',7,'Callback','showbridge(''filename'',''sub_makemovie'');');
            info.sub_movFILE = uicontrol(info.sub_movieHfig,'Style','text','Units','normalized','Position',[0.02 0.075 0.10 0.15],'String','file', ...
                                                            'HorizontalAlignment','right','FontWeight','bold','BackgroundColor',[0 0 0], ... 
                                                            'ForegroundColor',[1 1 1],'FontName','Times New Roman','FontSize',10);
            info.sub_movfile = uicontrol(info.sub_movieHfig,'Style','edit','Enable','off','Units','normalized','Position',[0.15 0.075 0.45 0.15],'HorizontalAlignment','left','String','');
       end
   case 'sub_moviSELECT'
       numselect = get(info.sub_moviemenu,'Value');
       
       if numselect == 1
           set(info.sub_MAKEMOVIE,'Enable','off');
           set(info.sub_movfile,'Enable','off');
       else
           set(info.sub_MAKEMOVIE,'Enable','on');
           set(info.sub_movfile,'Enable','on');
       end
   case 'sub_makemovie'
                  AMPL = get(info.amplify,'UserData');
              filename = info.filename;
        numselect_movi = get(info.sub_moviemenu,'Value');
        numselect_main = get(info.menu,'Value');
        
        movie_filename = get(info.sub_movfile,'String');
        set(info.sub_movfile,'String','');
        if isempty(movie_filename)
            disp(['No name given for movie file.  Please type a name in the edit box labeled ''filename''']);
            return
        end

        if numselect_main ~= 1
             % DEACTIVATE LINES (MODE & DISPLACEMENT)
             set(info.lines{numselect_main},'LineStyle','none');
             set(info.movelines{numselect_main},'LineStyle','none');
        end
         
         % RETRIEVE VARIABLES
             AMPL = get(info.amplify,'UserData');         AMPL = AMPL(numselect_movi-1);
         NODENUMS = info.nodenums;                 connections = info.elements(:,2:3);          diffmode = info.diffmode; 
                X = diffmode.X{1};                           Y = diffmode.Y{1};                        Z = diffmode.Z{1};
        thematrix = diffmode.all{numselect_movi};     wackynum = diffmode.wacky{numselect_movi};   isone = wackynum==1;
        resultant = diffmode.max_res{numselect_movi};
         
         % SET AXIS PROPERTIES TO PREVENT AUTOMATIC ZOOMING ADJUSTMENTS & CAMERA ANGLES
         axis off;       axis manual;       hold on;
        
         if isone
             diffXYZ = thematrix;
             
             % SORT DISPLACEMENTS BY CONNECTIONS
             diffX(1,:) = diffXYZ(1,connections(:,1));   diffX(2,:) = diffXYZ(1,connections(:,2));
             diffY(1,:) = diffXYZ(2,connections(:,1));   diffY(2,:) = diffXYZ(2,connections(:,2));
             diffZ(1,:) = diffXYZ(3,connections(:,1));   diffZ(2,:) = diffXYZ(3,connections(:,2));
                
             mov = moviein(115);

             % PLOT LINES
                       Xdat = X + AMPL*diffX;     Ydat = Y + AMPL*diffY;     Zdat = Z + AMPL*diffZ;
             temp_movieline = line(Xdat,Ydat,Zdat,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle','-','MarkerSize',8,'Parent',info.axes);
                     incr_X = AMPL*diffX/10;     incr_Y = AMPL*diffY/10;     incr_Z = AMPL*diffZ/10;
                
             for i=1:115
                 % PLACE FRAME IN MOVIE VARIABLE
                 onelove = getframe;
				 
                 % UPDATE MOVIE
                 delete(temp_movieline);
                    
                 Xdat = Xdat - incr_X;         Ydat = Ydat - incr_Y;         Zdat = Zdat - incr_Z;
                 temp_movieline = line(Xdat,Ydat,Zdat,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle','-','MarkerSize',8,'Parent',info.axes);

                 mov(:,i) = onelove;
                 
            end
            delete(temp_movieline);
            clear fileline diffXYZ diffX diffY diffZ Xdat Ydat Zdat temp_movieline
		
        else
             % INITIALIZE MOVIE VARIABLES
             framenum = 0;                 mov = moviein(wackynum);
                    
             % RECALL DISPLACEMENT VARIABLES
             diffX = diffmode.X{numselect_movi};
             diffY = diffmode.Y{numselect_movi};
             diffZ = diffmode.Z{numselect_movi};
             
%             % PACK MEMORY
%             cwd = pwd;                    cd(tempdir);
%             pack;                         cd(cwd);
                
             for kosovo = 1:wackynum
                 % RETRIEVE LINE VARIABLES
                 framenum = framenum + 1;
                  diffXYZ = thematrix(:,:,kosovo);
                 
                 % SORT DISPLACEMENTS BY CONNECTIONS
                 diffX(1,:) = diffXYZ(1,connections(:,1));   diffX(2,:) = diffXYZ(1,connections(:,2));
                 diffY(1,:) = diffXYZ(2,connections(:,1));   diffY(2,:) = diffXYZ(2,connections(:,2));
                 diffZ(1,:) = diffXYZ(3,connections(:,1));   diffZ(2,:) = diffXYZ(3,connections(:,2));

                 Xdat = X + AMPL*diffX;     Ydat = Y + AMPL*diffY;     Zdat = Z + AMPL*diffZ;
                temp_movieline = line(Xdat,Ydat,Zdat,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle','-','MarkerSize',8,'Parent',info.axes);
                 mov(:,framenum) = getframe(info.axes);
                    
                 % CLEAR VARIABLES & LINES
                 delete(temp_movieline);
                 clear fileline diffXYZ diffX diffY diffZ Xdat Ydat Zdat temp_movieline
             end
         end
            
         if numselect_main ~= 1
             % ACTIVATE LINES (MODE & DISPLACEMENT)
             currlinestyle = get(info.nomode,'UserData');         set(info.lines{numselect_main},'LineStyle',currlinestyle);
             currlinestyle = get(info.displace,'UserData');   set(info.movelines{numselect_main},'LineStyle',currlinestyle);
         end
            
         % RESET AXIS PROPERTIES TO NORMAL
         currvis = get(info.axesbt,'FontWeight');
         if strcmp(currvis,'bold')
             axis on;
         end
         axis manual;       hold on;
         
         if strcmp(computer,'PCWIN') | isunix
             movie2avi(mov,[movie_filename '.avi']);
             disp(['Saved movie ''' movie_filename '.avi' ''' to directory:  ' pwd]);
         else
             CMap = colormap;
             qtwrite(mov,CMap,[movie_filename '.qt']);
             disp(['Saved movie ''' movie_filename '.qt' ''' to directory:  ' pwd]);
         end
   case 'addmoddisp'
       iscreated = get(info.Hm_add,'UserData');
       if iscreated == 0
           set(info.Hm_add,'UserData',1,'Enable','off');
           info.sub_addHfig = figure('NumberTitle','off','Units','normalized','Position',[0.1500  0.2500  0.30  0.55],...
                                  'Name','Add/Remove','Color',[0 0 0],'UserData',Hfig, ...
                                  'menubar','none','CloseRequestFCN','showbridge(''filename'',''close_sub'');');
           info.sub_frame = uicontrol(info.sub_addHfig,'Style','frame','Units','normalized','Position',[0.0 0.0 1.0 0.2],'BackgroundColor',[0 0 0]);
           
            info.sub_name = uicontrol(info.sub_addHfig,'Style','edit','Units','normalized','Position',[0.2 0.16 0.5 0.05],'HorizontalAlignment','left','String',info.menuname{1});
            info.sub_file = uicontrol(info.sub_addHfig,'Style','edit','Units','normalized','Position',[0.2 0.09 0.5 0.05],'HorizontalAlignment','left','String',info.filename{1});
           if info.eigen(1) == -1
               info.sub_period = uicontrol(info.sub_addHfig,'Style','edit','Units','normalized','Position',[0.2 0.02 0.5 0.05],'HorizontalAlignment','left','String','No Value Given','Enable','off');
           else
               info.sub_period = uicontrol(info.sub_addHfig,'Style','edit','Units','normalized','Position',[0.2 0.02 0.5 0.05],'HorizontalAlignment','left','String',info.eigen(1));
           end
           
            info.sub_NAME = uicontrol(info.sub_addHfig,'Style','text','Units','normalized','Position',[0.02 0.16 0.16 0.05],'String','NAME', ...
                                                       'HorizontalAlignment','right','FontWeight','bold','BackgroundColor',[0 0 0], ... 
                                                       'ForegroundColor',[1 1 1],'FontName','Times New Roman','FontSize',10);
            info.sub_FILE = uicontrol(info.sub_addHfig,'Style','text','Units','normalized','Position',[0.02 0.09 0.16 0.05],'String','FILE', ...
                                                       'HorizontalAlignment','right','FontWeight','bold','BackgroundColor',[0 0 0], ... 
                                                       'ForegroundColor',[1 1 1],'FontName','Times New Roman','FontSize',10);
          info.sub_PERIOD = uicontrol(info.sub_addHfig,'Style','text','Units','normalized','Position',[0.02 0.02 0.16 0.05],'String','T',...
                                                       'HorizontalAlignment','right','FontWeight','bold','BackgroundColor',[0 0 0], ... 
                                                       'ForegroundColor',[1 1 1],'FontName','Times New Roman','FontSize',10);
           
           
           info.sub_ENTER = uicontrol(info.sub_addHfig,'Style','pushbutton','Units','normalized','Position',[0.45 0.23 0.2 0.04],'String','ENTER', ...
                                                    'HorizontalAlignment','center','FontWeight','bold','FontName','Times New Roman','FontSize',7, ...
                                                    'Visible','off','Enable','off', 'Callback','showbridge(''filename'',''sub_enter'');');
           info.sub_CANCEL = uicontrol(info.sub_addHfig,'Style','pushbutton','Units','normalized','Position',[0.75 0.23 0.2 0.04],'String','CANCEL', ...
                                                     'HorizontalAlignment','center','FontWeight','bold','FontName','Times New Roman','FontSize',7, ...
                                                     'Visible','off','Enable','off', 'Callback','showbridge(''filename'',''sub_cancel'');');
              info.sub_ADD = uicontrol(info.sub_addHfig,'Style','pushbutton','Units','normalized','Position',[0.75 0.15 0.2 0.04],'String','ADD', ...
                                                    'HorizontalAlignment','center','FontWeight','bold','FontName','Times New Roman','FontSize',7, ...
                                                    'Callback','showbridge(''filename'',''sub_add'');');
          info.sub_UPDATE = uicontrol(info.sub_addHfig,'Style','pushbutton','Units','normalized','Position',[0.75 0.095 0.2 0.04],'String','UPDATE', ...
                                                    'HorizontalAlignment','center','FontWeight','bold','FontName','Times New Roman','FontSize',7, ...
                                                    'Callback','showbridge(''filename'',''sub_update'');');
          info.sub_REMOVE = uicontrol(info.sub_addHfig,'Style','pushbutton','Units','normalized','Position',[0.75 0.04 0.2 0.04],'String','REMOVE', ...
                                                    'HorizontalAlignment','center','FontWeight','bold','FontName','Times New Roman','FontSize',7, ...
                                                    'Enable','off','Callback','showbridge(''filename'',''sub_remove'');');
                                         
                                                
            info.sub_menu = uicontrol(info.sub_addHfig,'Style','listbox','Units','normalized','Position',[0.1 0.3 0.8 0.65],'String',info.menulist,...
                                                       'Callback','showbridge(''filename'',''menu_info'')');
       end
   case 'close_sub'
       save_quest = 0;
       
       if isstruct(get(gcf,'UserData'))
           if isfield(info,'sub_addHfig');   delete(info.sub_addHfig);   end
           if isfield(info,'sub_movieHfig');   delete(info.sub_movieHfig);   end
       else
           if isfield(info,'sub_addHfig'); froggys=info.sub_addHfig; else froggys=-1; end
           if isfield(info,'sub_movieHfig'); jumpers=info.sub_movieHfig; else jumpers=-1;  end
           
           if jumpers == gcf
               save_quest = 1;
               delete(info.sub_movieHfig);
               set(info.Hm_movie,'UserData',0,'Enable','on');
               info = rmfield(info,'sub_movieHfig');        info = rmfield(info,'sub_moviemenu');
               info = rmfield(info,'sub_MAKEMOVIE');        info = rmfield(info,'sub_movFILE');
               info = rmfield(info,'sub_movfile');
           elseif froggys == gcf
               save_quest = 1;
               delete(info.sub_addHfig);
               set(info.Hm_add,'UserData',0,'Enable','on');
               info = rmfield(info,'sub_addHfig');   info = rmfield(info,'sub_frame');   info = rmfield(info,'sub_name');
               info = rmfield(info,'sub_file');      info = rmfield(info,'sub_period');  info = rmfield(info,'sub_NAME');
               info = rmfield(info,'sub_FILE');      info = rmfield(info,'sub_PERIOD');  info = rmfield(info,'sub_ENTER');
               info = rmfield(info,'sub_CANCEL');    info = rmfield(info,'sub_ADD');     info = rmfield(info,'sub_UPDATE');
               info = rmfield(info,'sub_REMOVE');    info = rmfield(info,'sub_menu');
           else
               if isfield(info,'sub_addHfig');   delete(info.sub_addHfig);   end
               if isfield(info,'sub_movieHfig');   delete(info.sub_movieHfig);   end
               delete(info.Hfig);
           end
       end
   case 'menu_info'
       save_quest = 0;
       
       filename = info.filename;
       menuname = info.menuname;
       period = info.eigen;
       
       numselect = get(info.sub_menu,'Value');
       
       set(info.sub_file,'String',filename{numselect});
       set(info.sub_name,'String',menuname{numselect});

       if period(numselect) == -1
           set(info.sub_period,'String','No Value Given');
       else
           set(info.sub_period,'String',period(numselect));
       end
       
       if numselect == 1
           set(info.sub_period,'Enable','off');
           set(info.sub_REMOVE,'Enable','off');
       else
           set(info.sub_period,'Enable','on');
           set(info.sub_REMOVE,'Enable','on');
       end
   case 'sub_enter'
       save_quest = 0;
          nextnum = length(info.filename) + 1;
          
       new_filename = get(info.sub_file,'String');
         new_period = str2num(get(info.sub_period,'String'));
       new_menuname = get(info.sub_name,'String');
       
       info.menulist = [info.menulist '|'];                    set(info.menu,'String',[info.menulist]);
       set(info.sub_menu,'String',[info.menulist]);            
       info.lines{nextnum} = [];                               info.movelines{nextnum} = [];
       info.eigen = [info.eigen -1];                            info.filename{nextnum} = [];
       info.menuname{nextnum} = [];                            
       set(info.sub_ENTER,'UserData',nextnum);
       menu_values = [ get(info.menu,'Value')     get(info.sub_menu,'Value') ];
       set(info.menu,'Value',nextnum);                          set(info.sub_menu,'Value',nextnum)
       if isfield(info,'sub_moviemenu');
           menu_values(3) = get(info.sub_moviemenu,'Value');
           set(info.sub_moviemenu,'String',[info.menulist],'Value',nextnum);
       end 
       info.menu_values = menu_values;
       
       set(Hfig,'UserData',info);
       checkerror=showbridge('filename','sub_update');  if checkerror == 1;  clear checkerror;  return; end
       showbridge('filename','sub_cancel');
       showbridge('filename','menu');
       set(info.sub_ENTER,'UserData','');
   case 'sub_cancel'
       set(info.sub_ENTER,'Visible','off','Enable','off');
       set(info.sub_CANCEL,'Visible','off','Enable','off');
       
       set(info.sub_ADD,'Enable','on');
       set(info.sub_UPDATE,'Enable','on');
       set(info.sub_REMOVE,'Enable','on');
       set(info.sub_menu,'Enable','on');
       
       showbridge('filename','menu_info');
   case 'sub_add'
       set(info.sub_ENTER,'Visible','on','Enable','on');
       set(info.sub_CANCEL,'Visible','on','Enable','on');
       
       set(info.sub_ADD,'Enable','off');
       set(info.sub_UPDATE,'Enable','off');
       set(info.sub_REMOVE,'Enable','off');
       set(info.sub_menu,'Enable','off');
       
       set(info.sub_period,'String','','Enable','on');
       set(info.sub_file,'String','');
       set(info.sub_name,'String','');
   case 'sub_update'
       menu_value = get(info.sub_menu,'Value');
                    
         filename = info.filename;
           period = info.eigen;
         menuname = info.menuname;
         menulist = info.menulist;
           
     new_filename = get(info.sub_file,'String');
       new_period = str2num(get(info.sub_period,'String'));
     new_menuname = get(info.sub_name,'String');
       
       if ~strcmp(new_filename,filename{menu_value})
           checkerror = showbridge(new_filename,'option',menu_value);
           if checkerror == 1;  return; end
           delete(info.lines{menu_value});
           delete(info.movelines{menu_value});
           
           info = get(Hfig,'UserData');
           info.filename{menu_value} = new_filename;
       end
       
       if ~strcmp(new_menuname,menuname{menu_value})
           % AUTOMATICALLY NAME IF NONE GIVEN
           if isempty(new_menuname) | [double(new_menuname) == [ones(1,length(new_menuname))*32]]
               chekneck = round(rand*5);
               
               switch chekneck
               case 1
                   new_menuname = ['Strategury #'  num2str(round(rand*1000))];
               case 2
                   new_menuname = ['Do you want fries with that? #'  num2str(round(rand*1000))];
               case 3
                   new_menuname = ['Oh... You''re from Wichita? #'  num2str(round(rand*1000))];
               case 4
                   new_menuname = ['MW says: I''m gonna make like a baby & head out #'  num2str(round(rand*1000))];
               case 5
                   new_menuname = ['They want me lucky charms! #'  num2str(round(rand*1000))];
               end
           end
           
           % UPDATE MENUNAME
           info.menuname{menu_value} = new_menuname;
           
           % UPDATE MENU LIST
           indices = find(menulist == '|');
           maxindi = length(indices)+1;
           
           if menu_value == 1
               menulist = [new_menuname menulist(indices(1):end)];
           elseif menu_value == maxindi
               menulist = [menulist(1:indices(end)) new_menuname];
           else
               menulist = [menulist(1:indices(menu_value-1)) ...
                               new_menuname menulist(indices(menu_value):end)];
           end
           
           info.menulist = menulist;
           set(info.menu,'String',menulist);
           set(info.sub_menu,'String',menulist);
           if isfield(info,'sub_moviemenu'); set(info.sub_moviemenu,'String',[info.menulist]); end
       end
       
       if isempty(new_period)
           info.eigen(menu_value) = -1;
           if get(info.menu,'Value') == menu_value
               set(info.disp,'String',num2str(new_period));
           end
       else
           if [new_period ~= period(menu_value)] & [menu_value ~= 1]
               info.eigen(menu_value) = new_period;
               if get(info.menu,'Value') == menu_value
                   set(info.disp,'String',num2str(new_period));
               end
           end
       end
   case 'sub_remove'
       deletethis = get(info.sub_menu,'Value');
       
       menu_num = get(info.menu,'Value');
       if isfield(info,'sub_moviemenu'); movi_num = get(info.sub_moviemenu,'Value'); end
       
       begin = 1;                  ending = length(info.filename);
       begmid = deletethis-1;      endmid = deletethis + 1;
       
       indices = find(info.menulist == '|');
       AMPL = get(info.amplify,'UserData');
       diffmode = info.diffmode;
       
       if deletethis == ending
           nexttolast = ending - 1;

           % RESET POSITION OF HIGHLIGHT
           set(info.sub_menu,'Value',nexttolast)
           if menu_num == deletethis; set(info.menu,'Value',nexttolast); end
           if exist('movi_num')
               if movi_num == deletethis; set(info.sub_moviemenu,'Value',nexttolast); end
           end
           
           % UPDATE MENU INFORMATION & CALLBACKs
           showbridge('filename','menu');
           showbridge('filename','menu_info');
       end
       
       if deletethis == ending
           % SOME USEFUL VARIABLES
           laststr = indices(length(indices))-1;
           
           % RESET VALUE OF INFO.MENULIST & INFO.EIGEN
           info.menulist = info.menulist(1:laststr);
           info.eigen = [ info.eigen(begin:nexttolast) ];
           AMPL = [AMPL(begin:[nexttolast-1])];
           
           % CREATE TEMPORARY VARIABLE HOLDING LINES VALUES
           [temp_lines{begin:nexttolast}] = deal(info.lines{begin:nexttolast});
           
           % CREATE TEMPORARY VARIABLE HOLDING MOVELINES VALUES
           [temp_movelines{begin:nexttolast}] = deal(info.movelines{begin:nexttolast});
           
           % CREATE TEMPORARY VARIABLE HOLDING FILENAME VALUES
           [temp_filename{begin:nexttolast}] = deal(info.filename{begin:nexttolast});
           
           % CREATE TEMPORARY VARIABLE HOLDING MENUNAME VALUES
           [temp_menuname{begin:nexttolast}] = deal(info.menuname{begin:nexttolast});
           
           % CREATE TEMPORARY VARIABLE HOLDING DIFFMODE VALUES
           [temp_diffwac{begin:nexttolast}] = deal(diffmode.wacky{begin:nexttolast});
           [temp_diffres{begin:nexttolast}] = deal(diffmode.max_res{begin:nexttolast});
           [temp_diffall{begin:nexttolast}] = deal(diffmode.all{begin:nexttolast});
           
           [temp_diffX{begin:nexttolast}] = deal(diffmode.X{begin:nexttolast});
           [temp_diffY{begin:nexttolast}] = deal(diffmode.Y{begin:nexttolast});
           [temp_diffZ{begin:nexttolast}] = deal(diffmode.Z{begin:nexttolast});
           
           [temp_moveX{begin:nexttolast}] = deal(diffmode.moveX{begin:nexttolast});
           [temp_moveY{begin:nexttolast}] = deal(diffmode.moveY{begin:nexttolast});
           [temp_moveZ{begin:nexttolast}] = deal(diffmode.moveZ{begin:nexttolast});
       else
           % RESET VALUE OF INFO.MENULIST & INFO.EIGEN
           info.menulist = [ info.menulist(1:[indices(deletethis-1)-1]) info.menulist(indices(deletethis):end) ];
           info.eigen = [ info.eigen(begin:begmid) info.eigen(endmid:ending)];
           AMPL = [AMPL(begin:[begmid-1])  AMPL([endmid-1]:end)];
           
           % CREATE TEMPORARY VARIABLE HOLDING LINES VALUES
           [temp_lines{begin:begmid}] = deal(info.lines{begin:begmid}); 
           [temp_lines{deletethis:[ending-1]}] = deal(info.lines{endmid:ending});
           
           % CREATE TEMPORARY VARIABLE HOLDING MOVELINES VALUES
           [temp_movelines{begin:begmid}] = deal(info.movelines{begin:begmid}); 
           [temp_movelines{deletethis:[ending-1]}] = deal(info.movelines{endmid:ending});
           
           % CREATE TEMPORARY VARIABLE HOLDING FILENAME VALUES
           [temp_filename{begin:begmid}] = deal(info.filename{begin:begmid}); 
           [temp_filename{deletethis:[ending-1]}] = deal(info.filename{endmid:ending});
           
           % CREATE TEMPORARY VARIABLE HOLDING MENUNAME VALUES
           [temp_menuname{begin:begmid}] = deal(info.menuname{begin:begmid}); 
           [temp_menuname{deletethis:[ending-1]}] = deal(info.menuname{endmid:ending});
           
           % CREATE TEMPORARY VARIABLE HOLDING DIFFMODE VALUES
           [temp_diffwac{begin:begmid}] = deal(diffmode.wacky{begin:begmid}); 
           [temp_diffwac{deletethis:[ending-1]}] = deal(diffmode.wacky{endmid:ending});
           
           [temp_diffres{begin:begmid}] = deal(diffmode.max_res{begin:begmid}); 
           [temp_diffres{deletethis:[ending-1]}] = deal(diffmode.max_res{endmid:ending});
           
           [temp_diffall{begin:begmid}] = deal(diffmode.all{begin:begmid}); 
           [temp_diffall{deletethis:[ending-1]}] = deal(diffmode.all{endmid:ending});
           
           [temp_diffX{begin:begmid}] = deal(diffmode.X{begin:begmid}); 
           [temp_diffX{deletethis:[ending-1]}] = deal(diffmode.X{endmid:ending});
           
           [temp_diffY{begin:begmid}] = deal(diffmode.Y{begin:begmid}); 
           [temp_diffY{deletethis:[ending-1]}] = deal(diffmode.Y{endmid:ending});
           
           [temp_diffZ{begin:begmid}] = deal(diffmode.Z{begin:begmid}); 
           [temp_diffZ{deletethis:[ending-1]}] = deal(diffmode.Z{endmid:ending});
           
           [temp_moveX{begin:begmid}] = deal(diffmode.moveX{begin:begmid}); 
           [temp_moveX{deletethis:[ending-1]}] = deal(diffmode.moveX{endmid:ending});
           
           [temp_moveY{begin:begmid}] = deal(diffmode.moveY{begin:begmid}); 
           [temp_moveY{deletethis:[ending-1]}] = deal(diffmode.moveY{endmid:ending});
           
           [temp_moveZ{begin:begmid}] = deal(diffmode.moveZ{begin:begmid}); 
           [temp_moveZ{deletethis:[ending-1]}] = deal(diffmode.moveZ{endmid:ending});
       end
       
       % SAVE NEW DIFFMODE FIELDS IN TEMP DIFFMODE VARIABLE
       temp_diffmode.X = temp_diffX;                 temp_diffmode.moveX = temp_moveX;
       temp_diffmode.Y = temp_diffY;                 temp_diffmode.moveY = temp_moveY;
       temp_diffmode.Z = temp_diffZ;                 temp_diffmode.moveZ = temp_moveZ;
     temp_diffmode.all = temp_diffall;               temp_diffmode.wacky = temp_diffwac;
 temp_diffmode.max_res = temp_diffres;     
       
       % DELETE GUI OBJECTS
       delete(info.lines{deletethis});                  delete(info.movelines{deletethis});
       
       % UPDATE INFORMATION (REMOVE INFO OF MODE)
       set(info.amplify,'UserData',AMPL);
       info.lines = temp_lines;                         info.movelines = temp_movelines;
       info.filename = temp_filename;                   info.menuname = temp_menuname;
       set(Hfig,'UserData',info);                       info.diffmode = temp_diffmode;

       if deletethis ~= ending
           showbridge('filename','menu_info');
           
           % UPDATE MAIN GRAPHING MENU
           if menu_num == deletethis
               set(info.nomode,'Enable','off');     set(info.displace,'Enable','off');
               set(info.amplify,'Enable','off','String','');
               set(info.disp,'Enable','off','String','','ForegroundColor',[1 1 1]);
               set(info.T,'ForegroundColor',[0 0 0]);
               set(info.seconds,'ForegroundColor',[0 0 0]);
               
               % ACTIVATE LINES (MODE & DISPLACEMENT)
               currlinestyle = get(info.nomode,'UserData');         set(info.lines{deletethis},'LineStyle',currlinestyle);
               currlinestyle = get(info.displace,'UserData');   set(info.movelines{deletethis},'LineStyle',currlinestyle);
               
               % ENABLE EIGEN, DISPLAY, DISPLACEMENT, & MODE BUTTONS
               set(info.nomode,'Enable','on');      set(info.displace,'Enable','on');
               set(info.T,'ForegroundColor',[1 1 0]);
               set(info.seconds,'ForegroundColor',[1 1 0]);
               
               if info.eigen(deletethis) == -1
                   set(info.disp,'Enable','on','String','No Value','ForegroundColor',[1 1 0]);
               else
                   set(info.disp,'Enable','on','String',num2str(info.eigen(deletethis)),'ForegroundColor',[1 1 0]);
               end
               
               set(info.amplify,'Enable','on','String',AMPL(deletethis-1));
           elseif menu_num > deletethis
               old_k = get(info.menu,'UserData');
               set(info.menu,'UserData',old_k-1);
               set(info.menu,'Value',menu_num-1);
           end
           
           % UPDATE MOVIE MENU, IF OPEN
           if exist('movi_num')
               if movi_num > deletethis
                   set(info.sub_moviemenu,'Value',movi_num-1);
               end
           end
       end
       
       info.magicnum = info.magicnum - 1;
       
       % UPDATE MENULIST IN GUIs
       set(info.menu,'String',info.menulist);           set(info.sub_menu,'String',info.menulist);
       if isfield(info,'sub_moviemenu'); set(info.sub_moviemenu,'String',info.menulist); end
   case 'nostruct'         
       isbold = get(info.nostruct,'FontWeight');
       if strcmp(isbold,'bold')
           set(info.lines{1},'LineStyle','none'); set(info.nostruct,'FontWeight','normal');
       else
           set(info.lines{1},'LineStyle','-');    set(info.nostruct,'FontWeight','bold');
       end
   case 'nodebutton'       
       currmarker = get(info.lines{1}(1),'Marker');
       if strcmp(currmarker,'none')
           set(info.lines{1},'Marker','.');   set(info.nodebt,'FontWeight','bold');
       else
           set(info.lines{1},'Marker','none');   set(info.nodebt,'FontWeight','normal');
       end
   case 'axesbutton'       
       currvis = get(info.axes,'Visible');
       if strcmp(currvis,'on')
           set(info.axes,'Visible','off');  set(info.axesbt,'FontWeight','normal');
       else
           set(info.axes,'Visible','on');   set(info.axesbt,'FontWeight','bold');
       end
   case 'eps'
             k = get(info.menu,'Value');
       nameroo = info.nameroo;   number = get(info.eps,'UserData');
        number = number + 1;       set(info.eps,'UserData',number);
        set(info.lines{1},'LineWidth',[2.0]);
        if k~=1,
           set(info.lines{k},'Color',[0 0 1],'LineWidth',[0.5]);
           set(info.movelines{k},'Color',[0 0 1],'LineStyle','-.');
        end
        picfilename = [nameroo '_pic' num2str(number)];
        print(Hfig,'-noui','-loose','-depsc2','-r600',picfilename);
        disp(['Printed ''' picfilename '.eps' ''' to directory:  ' pwd]);
        set(info.lines{1},'LineWidth',[1.5]);
        if k~=1,
           set(info.lines{k},'Color',[1 1 0],'LineWidth',[1.0]);
           set(info.movelines{k},'Color',[1 1 1],'LineStyle',':');
        end
   case 'rotate'           
       isbold_rot = get(info.rotate,'FontWeight');
       if strcmp(isbold_rot,'bold')
           rotate3d
           set(info.rotate,'FontWeight','normal');
       else
           rotate3d
           set(info.rotate,'FontWeight','bold');
       end
       
       % DESELECT ZOOM BECAUSE SELECTING ROTATION PREVENTS ZOOM
       isbold_zoom = get(info.zoom,'FontWeight');
       if strcmp(isbold_zoom,'bold')
            set(info.zoom,'FontWeight','normal');
       end
   case 'zoom'              
       isbold_zoom = get(info.zoom,'FontWeight');
       if strcmp(isbold_zoom,'bold')
            zoom(Hfig,'off');
            set(info.zoom,'FontWeight','normal');
       else
            zoom(Hfig,'on');
            set(info.zoom,'FontWeight','bold');
       end
       
       % DESELECT ROTATION BECAUSE SELECTING ZOOM PREVENTS ROTATION
       isbold_rot = get(info.rotate,'FontWeight');
       if strcmp(isbold_rot,'bold')
           set(info.rotate,'FontWeight','normal');
       end
   case 'displace'          
            k = get(info.menu,'Value');
       isbold = get(info.displace,'FontWeight');
       if strcmp(isbold,'bold')
            set(info.movelines{k},'LineStyle','none');
            set(info.displace,'FontWeight','normal','UserData','none');
       else
            set(info.movelines{k},'LineStyle',':');
            set(info.displace,'FontWeight','bold','UserData',':');
       end
   case 'nomode'           
            k = get(info.menu,'Value');
       isbold = get(info.nomode,'FontWeight');
       if strcmp(isbold,'bold')
           set(info.lines{k},'LineStyle','none')
           set(info.nomode,'UserData','none','FontWeight','normal');
       else
           set(info.lines{k},'LineStyle','--');
           set(info.nomode,'UserData','--','FontWeight','bold');
       end
   case 'amplify'
       % SAVE INFORMATION OF AMPLIFICATION STRENGTH
             k = get(info.menu,'Value');          NODENUMS = info.nodenums;
          AMPL = get(info.amplify,'UserData');     newAMPL = str2num(get(info.amplify,'String'));
     AMPL(k-1) = newAMPL;                         diffmode = info.diffmode;
       set(info.amplify,'UserData',AMPL);
       
       % RETRIEVE SAVED VARIABLES
           X = diffmode.X{1};          Y = diffmode.Y{1};          Z = diffmode.Z{1};        diffXYZ = diffmode.all{k};
       diffX = diffmode.X{k};      diffY = diffmode.Y{k};      diffZ = diffmode.Z{k};
       moveX = diffmode.moveX{k};  moveY = diffmode.moveY{k};  moveZ = diffmode.moveZ{k};
       
       % PLOT LINES SHOWING NODAL DISPLACEMENT
       moveX(2,:) = moveX(1,:) + newAMPL*diffXYZ(1,NODENUMS);
       moveY(2,:) = moveY(1,:) + newAMPL*diffXYZ(2,NODENUMS);
       moveZ(2,:) = moveZ(1,:) + newAMPL*diffXYZ(3,NODENUMS);
       
       % RETRIEVE LINESTYLE
           currlinestyle = get(info.nomode,'UserData');
       currmovelinestyle = get(info.displace,'UserData');
       
       % DELETE OLD LINE
       delete(info.lines{k});     delete(info.movelines{k});
       
       % CREATE NEW LINES
       info.lines{k} = line(X + newAMPL.*diffX,Y + newAMPL.*diffY,Z + newAMPL.*diffZ,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle',currlinestyle,'MarkerSize',8);
   info.movelines{k} = line(moveX,moveY,moveZ,'Color',[0.753 0.753 0.753],'LineWidth',[0.5],'LineStyle',currmovelinestyle,'MarkerSize',8);
   case 'menu'             
       k = get(info.menu,'Value');          old_k = get(info.menu,'UserData');
       if old_k~=k
           set(info.menu,'UserData',k);
           if old_k~=1
               % DEACTIVATE LINES (MODE & DISPLACEMENT)
               set(info.lines{old_k},'LineStyle','none');
               set(info.movelines{old_k},'LineStyle','none');
               
               % DISABLE EIGEN, DISPLAY, DISPLACEMENT, & MODE BUTTONS
               set(info.nomode,'Enable','off');     set(info.displace,'Enable','off');
               set(info.amplify,'Enable','off','String','');
               set(info.disp,'Enable','off','String','','ForegroundColor',[1 1 1]);
               set(info.T,'ForegroundColor',[0 0 0]);
               set(info.seconds,'ForegroundColor',[0 0 0]);
           end
           
           if k~=1
               % ACTIVATE LINES (MODE & DISPLACEMENT)
               currlinestyle = get(info.nomode,'UserData');         set(info.lines{k},'LineStyle',currlinestyle);
               currlinestyle = get(info.displace,'UserData');   set(info.movelines{k},'LineStyle',currlinestyle);
               
               % ENABLE EIGEN, DISPLAY, DISPLACEMENT, & MODE BUTTONS
               set(info.nomode,'Enable','on');      set(info.displace,'Enable','on');
               set(info.T,'ForegroundColor',[1 1 0]);
               set(info.seconds,'ForegroundColor',[1 1 0]);
               if info.eigen(k) == -1
                   set(info.disp,'Enable','on','String','No Value','ForegroundColor',[1 1 0]);
               else
                   set(info.disp,'Enable','on','String',num2str(info.eigen(k)),'ForegroundColor',[1 1 0]);
               end
               AMPL = get(info.amplify,'UserData');   set(info.amplify,'Enable','on','String',AMPL(k-1));
           end
       end
   end
end
    

if nargin == 3
    Hfig = get(gcbf,'UserData');   set(Hfig,'HandleVisibility','on');
    save_quest = 1;                checkerror = 0;
    
    info = get(Hfig,'UserData');
    
    AMPL = get(info.amplify,'UserData');
    
    % OPEN OUTPUT FILE, CATCH IF FILE NOT AVAILABLE
    fid = fopen([nameroo],'rt');     % open output file
    
    % CHECK IF FILE IS PRESENT
    if fid == -1
        disp(['could not find the file:  ' nameroo    ' -- ACTION CANCELED']);
        checkerror = 1;
        notnextnum = get(info.sub_ENTER,'UserData')-1;
        menu_values = info.menu_values;
        info = rmfield(info,'menu_values');  
        if patooi > [notnextnum]
            set(info.sub_ENTER,'UserData','');
            showbridge('filename','sub_remove');
            set(info.menu,'Value',menu_values(1));
            set(info.sub_menu,'Value',menu_values(2));
            showbridge('filename','menu');
            if length(menu_values)==3;    set(info.sub_moviemenu,'Value',menu_values(3));    end
            showbridge('filename','sub_cancel');
            
        end
        return
    else
        AMPL(patooi-1) = 200;                     NODENUMS = info.nodenums;      diffmode = info.diffmode; 
                   X = diffmode.X{1};                    Y = diffmode.Y{1};             Z = diffmode.Z{1};
         connections = info.elements(:,2:3);         NODES = info.nodes;    
            
        if info.ndm == 2
            XYZ = NODES;     XYZ(:,3) = 0;     XYZ = XYZ';
        else
            XYZ = NODES';
        end
                
        frewind(fid);            % sets the file position indicator to the beginning
        
        % PARSE NUMBERS INTO VARIABLE 'FILELINE'
        fileline = fgetl(fid);   fileline = str2num(fileline);   numcol = size(fileline,2);
        
        % SORT DISPLACEMENTS ACCORDING TO NODES AND DOF
        diffXYZ(1,NODENUMS) = fileline(1:3:numcol);
        diffXYZ(2,NODENUMS) = fileline(2:3:numcol);
        diffXYZ(3,NODENUMS) = fileline(3:3:numcol);
        
        % NORMALIZE DISPLACEMENT
        resultant = sqrt([sum(diffXYZ.^2,2)]);
        diffXYZ = diffXYZ/max(resultant);
        
        % SORT DISPLACEMENTS BY CONNECTIONS
        diffX(1,:) = diffXYZ(1,connections(:,1));   diffX(2,:) = diffXYZ(1,connections(:,2));
        diffY(1,:) = diffXYZ(2,connections(:,1));   diffY(2,:) = diffXYZ(2,connections(:,2));
        diffZ(1,:) = diffXYZ(3,connections(:,1));   diffZ(2,:) = diffXYZ(3,connections(:,2));
        
        % PLOT LINES SHOWING NODAL DISPLACEMENT (SHOWING MOVEMENT OF NODE FROM ORIGIN TO DISPLACED POSITION)
        moveX(1,:) = XYZ(1,NODENUMS);   moveX(2,:) = moveX(1,:) + AMPL(patooi-1)*diffXYZ(1,NODENUMS);
        moveY(1,:) = XYZ(2,NODENUMS);   moveY(2,:) = moveY(1,:) + AMPL(patooi-1)*diffXYZ(2,NODENUMS);
        moveZ(1,:) = XYZ(3,NODENUMS);   moveZ(2,:) = moveZ(1,:) + AMPL(patooi-1)*diffXYZ(3,NODENUMS);
               
        % PLOT LINES
        Xdat = X + AMPL(patooi-1)*diffX;     Ydat = Y + AMPL(patooi-1)*diffY;     Zdat = Z + AMPL(patooi-1)*diffZ;
        
        if ~isempty(get(info.sub_ENTER,'UserData'))
            new_LineStyle = 'none';
            new_moveLineStyle =  'none';
        else
            new_LineStyle = get(info.lines{patooi},'LineStyle');               new_LineStyle = new_LineStyle{1};
            new_moveLineStyle = get(info.movelines{patooi},'LineStyle');   new_moveLineStyle = new_moveLineStyle{1};
        end
        
        info.lines{patooi} = line(Xdat,Ydat,Zdat,'Color',[1 1 0],'LineWidth',[1.0],'LineStyle',new_LineStyle,'MarkerSize',8,'Parent',info.axes);
        info.movelines{patooi} = line(moveX,moveY,moveZ,'Color',[0.753 0.753 0.753],'LineWidth',[0.5],'LineStyle',new_moveLineStyle,'MarkerSize',8,'Parent',info.axes);

        % SAVE ALL DISPLACEMENTS IN THE MATRIX
        thematrix = diffXYZ;
        wackynum = 1;
        
        while ~feof(fid)
            fileline = fgetl(fid);   fileline = str2num(fileline);
            % SORT DISPLACEMENTS ACCORDING TO NODES AND DOF
            diffXYZ(1,NODENUMS) = fileline(1:3:numcol);
            diffXYZ(2,NODENUMS) = fileline(2:3:numcol);
            diffXYZ(3,NODENUMS) = fileline(3:3:numcol);
                        diffXYZ = diffXYZ/max(resultant);

            wackynum = wackynum + 1;
            thematrix(:,:,wackynum) = diffXYZ;
        end
        
        % STORE DISPLACEMENTS FOR SHAPES OF EIGEN MODES
          diffmode.all{patooi} = thematrix; diffmode.wacky{patooi} = wackynum;  diffmode.max_res{patooi} = max(resultant);
            diffmode.X{patooi} = diffX;         diffmode.Y{patooi} = diffY;           diffmode.Z{patooi} = diffZ;
        diffmode.moveX{patooi} = moveX;     diffmode.moveY{patooi} = moveY;       diffmode.moveZ{patooi} = moveZ;
        
        % CLOSE FILE & CLEAR VARIABLES
        fclose(fid);
        clear fid fileline diffXYZ diffX diffY diffZ
        
        % STORE MORE PARSED INFORMATION INTO 'INFO' VARIALBE
        info.diffmode = diffmode;
        set(info.amplify,'UserData',AMPL);
    end
end
    
if save_quest == 1
    % SAVE 'INFO' VARIABLE IN USERDATA
    set(Hfig,'UserData',info)
end

% SET SO HANDLES CAN ONLY BE USED BY CALLBACKS
%set(Hfig,'HandleVisibility','callback')
